#
# Conditional build
%bcond_without	tcl		# disable tcl support
%bcond_without	tests	# do not run "make check"
%bcond_without	docs	# do not build documentation
#
# NOTE:
# - /etc/localtime must be present for tests to work
#
# TODO:
# - script for rpm to autoprovides/autorequires R internals
#
%include	/usr/lib/rpm/macros.perl
Summary:	A language for data analysis and graphics
Summary(pl.UTF-8):	Język do analizy danych oraz grafiki
Name:		R
Version:	3.0.2
Release:	3
License:	Mixed (distributable), mostly GPL v2+
Group:		Development/Languages
# CRAN master site: ftp://cran.r-project.org/pub/R/src/
Source0:	ftp://stat.ethz.ch/R-CRAN/src/base/R-3/%{name}-%{version}.tar.gz
# Source0-md5:	f9a8374736e7650e4848f33e2e3bbee3
Source1:	%{name}.desktop
Source2:	%{name}.xpm
URL:		http://www.r-project.org/
BuildRequires:	autoconf >= 2.62
BuildRequires:	automake
BuildRequires:	blas-devel >= 3.2.2-2
BuildRequires:	bzip2-devel >= 1.0.6
BuildRequires:	cairo-devel >= 1.6
BuildRequires:	gcc-fortran
BuildRequires:	gettext-devel >= 0.14.5
BuildRequires:	lapack-devel >= 3.2.2-2
BuildRequires:	libicu-devel
BuildRequires:	libjpeg-devel >= 6b
BuildRequires:	libpng-devel >= 1.2.7
BuildRequires:	libstdc++-devel
BuildRequires:	libtiff-devel
BuildRequires:	libtool >= 2:2.0
BuildRequires:	libxml2-devel >= 2.6.26
BuildRequires:	pango-devel
BuildRequires:	pcre-devel >= 7.6
BuildRequires:	perl-base >= 1:5.6
BuildRequires:	pkgconfig
BuildRequires:	readline-devel
BuildRequires:	rpm-perlprov
%if %{with tcl}
BuildRequires:	tcl-devel >= 8.4
BuildRequires:	tk-devel >= 8.4
%endif
%if %{with docs}
BuildRequires:	tetex-dvips
BuildRequires:	tetex-latex
BuildRequires:	tetex-pdftex
BuildRequires:	texinfo-texi2dvi >= 4.7
%endif
BuildRequires:	xorg-lib-libX11-devel
BuildRequires:	xorg-lib-libXmu-devel
BuildRequires:	xorg-lib-libXt-devel
BuildRequires:	xz-devel >= 4.999
BuildRequires:	zip
BuildRequires:	zlib-devel >= 1.2.3
#Requires:	lpr
Requires(post):	perl-base
Requires(post):	textutils
Requires:	blas >= 3.2.2-2
Suggests:	rkward
Obsoletes:	R-base
Obsoletes:	R-contrib
Obsoletes:	R-recommended
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
A system for statistical computation and graphics. R consists of a
language plus a run-time environment with graphics, a debugger, access
to certain system functions, and the ability to run programs stored in
script files.

The design of R has been heavily influenced by two existing languages:
Becker, Chambers & Wilks' S and Sussman's Scheme. Whereas the
resulting language is very similar in appearance to S, the underlying
implementation and semantics are derived from Scheme.

%description -l pl.UTF-8
System do obliczeń statystycznych i grafiki. R składa się z języka
oraz środowiska uruchomieniowego z grafiką, debuggerem, dostępem do
niektórych funkcji systemowych oraz możliwością uruchamiania programów
zapisanych w skryptach.

Język R był zainspirowany dwoma istniejącymi językami: S (Beckera,
Chambersa i Wilksa) oraz Scheme (Sussmana). R jest podobny do S, ale
implementacja i semantyka wywodzi się ze Scheme.

%package java-tools
Summary:	R Java tools
Summary(pl.UTF-8):	Narzędzia R w Javie
Group:		Development/Tools
Requires:	%{name} = %{version}-%{release}

%description java-tools
R Java classes.

%description java-tools -l pl.UTF-8
Narzędzia R w Javie.

%prep
%setup -q

%build
%{__aclocal} -I m4
%{__autoconf}
install -d build
cd build
../%configure \
	F77=gfortran \
	FC=gfortran \
	--enable-R-shlib \
	--enable-largefile \
	--with-ICU \
	--with-blas \
	--with-cairo \
	--with-jpeglib \
	--with-lapack \
	--with-libpng \
	--with-readline \
	--with-recommended-packages \
	--with-system-bzlib \
	--with-system-pcre \
	--with-system-xz \
	--with-system-zlib \
%if %{with tcl}
	--with-tcltk \
	--with-tcl-config=/usr/lib/tclConfig.sh \
	--with-tk-config=/usr/lib/tkConfig.sh \
%else
	--without-tcltk \
%endif
	--with-x

%{__make} -j1

%if %{with tests}
%{__make} check
%endif

%if %{with docs}
%{__make} docs pdf info
%endif

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{_bindir},%{_mandir}/man1,%{_libdir}/R,%{_includedir},%{_desktopdir},%{_pixmapsdir}}

%{__make} -C build -j1 install \
	DESTDIR=$RPM_BUILD_ROOT

install %{SOURCE1} $RPM_BUILD_ROOT%{_desktopdir}
install %{SOURCE2} $RPM_BUILD_ROOT%{_pixmapsdir}

ln -sf %{_libdir}/R/lib/libR.so $RPM_BUILD_ROOT%{_libdir}

mv $RPM_BUILD_ROOT%{_libdir}/%{name}/include $RPM_BUILD_ROOT%{_includedir}/R
ln -sf %{_includedir}/R $RPM_BUILD_ROOT%{_libdir}/R/include

gen_lang() {
	dir="$1"
	for d in $RPM_BUILD_ROOT${dir}/* ; do
		bd=$(basename $d)
		lang="${bd%@*}"
		echo "%lang($lang) ${dir}/${bd}"
	done
}

for moddir in $RPM_BUILD_ROOT%{_libdir}/R/library/* ; do
	module=$(basename $moddir)
	echo "%dir %{_libdir}/R/library/${module}"
	if [ "$module" = "translations" ]; then
		for f in $moddir/* ; do
			bf=$(basename $f)
			case "$bf" in
			  DESCRIPTION|en|en@quot)
				echo "%{_libdir}/R/library/${module}/${bf}"
				;;
			  *)
				echo "%lang(${bf}) %{_libdir}/R/library/${module}/${bf}"
				;;
			esac
		done
	else
		for f in $moddir/* ; do
			bf=$(basename $f)
			case "$bf" in
			  po)
				echo "%dir %{_libdir}/R/library/${module}/po"
				gen_lang %{_libdir}/R/library/${module}/po
				;;
			  libs)
				echo "%dir %{_libdir}/R/library/${module}/libs"
				echo "%attr(755,root,root) %{_libdir}/R/library/${module}/libs/*.so"
				;;
			  *)
				echo "%{_libdir}/R/library/${module}/${bf}"
				;;
			esac
		done
	fi
done > R.files

# just GPL
%{__rm} $RPM_BUILD_ROOT%{_libdir}/R/doc/COPYING
# packaged as %doc
%{__rm} $RPM_BUILD_ROOT%{_libdir}/R/doc/{AUTHORS,COPYRIGHTS,FAQ,NEWS.rds,THANKS}
%if %{with docs}
# pdf version of NEWS
%{__rm} $RPM_BUILD_ROOT%{_libdir}/R/NEWS.pdf
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files -f R.files
%defattr(644,root,root,755)
%doc NEWS* README doc/{AUTHORS,COPYRIGHTS,FAQ,RESOURCES,THANKS}
%attr(755,root,root) %{_bindir}/R
%attr(755,root,root) %{_bindir}/Rscript
%dir %{_libdir}/R
%dir %{_libdir}/R/lib
%attr(755,root,root) %{_libdir}/R/lib/libR.so
%attr(755,root,root) %{_libdir}/libR.so
%{_libdir}/R/COPYING
%{_libdir}/R/NEWS*
%{_libdir}/R/SVN-REVISION
%attr(755,root,root) %{_libdir}/R/bin
%exclude %{_libdir}/R/bin/javareconf
# %{_libdir}/R/doc %except %{_libdir}/R/doc/html/{packages.html,search/index.txt}
%dir %{_libdir}/R/doc
%{_libdir}/R/doc/[KRm]*
%{_libdir}/R/doc/CRAN_mirrors.csv
%dir %{_libdir}/R/doc/html
%{_libdir}/R/doc/html/*.css
%{_libdir}/R/doc/html/[NRSa-lr-u]*.html
%{_libdir}/R/doc/html/packages-head*.html
%{_libdir}/R/doc/html/favicon.ico
%{_libdir}/R/doc/html/*.jpg
%ghost %{_libdir}/R/doc/html/packages.html
%{_libdir}/R/etc
%{_libdir}/R/include
%dir %{_libdir}/R/library
# library files list is autogenerated (see R.files above)
%attr(755,root,root) %{_libdir}/R/modules
%dir %{_libdir}/R/share
%{_libdir}/R/share/R
%{_libdir}/R/share/dictionaries
%{_libdir}/R/share/encodings
%{_libdir}/R/share/licenses
%{_libdir}/R/share/make
%{_libdir}/R/share/sh
%{_libdir}/R/share/texmf
%{_desktopdir}/R.desktop
%{_pixmapsdir}/R.xpm
%{_includedir}/R
%{_pkgconfigdir}/libR.pc
%{_mandir}/man1/R.1*
%{_mandir}/man1/Rscript*

%files java-tools
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/R/bin/javareconf
%{_libdir}/R/share/java
%changelog
* Fri Nov 01 2013 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/R.git;a=log;h=master

* Fri Nov 01 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 272b8e7
- release 3 (by relup.sh)

* Tue Oct 29 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 114f1b1
- release 2 (by relup.sh)

* Thu Oct 03 2013 Jakub Bogusz <qboosh@pld-linux.org> a7b0ffa
- NEWS.pdf cleanup when building with docs

* Mon Sep 30 2013 wrobell <wrobell@pld-linux.org> 3c6431b
- ver. 3.0.2
- built without docs conditional
- included all the NEWS files
- the removal of NEWS.pdf failed "without doc" conditional, so removed the
  line

* Thu May 23 2013 Jakub Bogusz <qboosh@pld-linux.org> ca8aef4
- check-files cleanup

* Wed May 22 2013 wrobell <wrobell@pld-linux.org> ee368cd
- ver. 3.0.1

* Sun Apr 14 2013 Jakub Bogusz <qboosh@pld-linux.org> 333306e
- package remaining files
- mark translations module with %%lang()

* Fri Apr 05 2013 wrobell <wrobell@pld-linux.org> 07f759a
- rel. 1

* Fri Apr 05 2013 wrobell <wrobell@pld-linux.org> 98d6655
- ver. 3.0.0 (nfy)

* Sun Mar 10 2013 Jakub Bogusz <qboosh@pld-linux.org> d396a0c
- updated to 2.15.3

* Sun Nov 11 2012 Jakub Bogusz <qboosh@pld-linux.org> ef6bf10
- pl for -java-tools

* Mon Oct 29 2012 wrobell <wrobell@pld-linux.org> ea85d5c
- ver. 2.5.2

* Wed Oct 17 2012 Jan Rękorajski <baggins@pld-linux.org> 561bbd9
- fixed Tcl/Tk support
- rel 7

* Fri Sep 28 2012 wrobell <wrobell@pld-linux.org> 4b82ebd
- rel. 6

* Fri Sep 28 2012 wrobell <wrobell@pld-linux.org> 92428cc
- added docs conditional build
- fixed java-tools subpackage group
- javareconf still needs to be packaged :/

* Tue Sep 25 2012 wrobell <wrobell@pld-linux.org> 1eca4d7
- s/java/java-tools/

* Tue Sep 25 2012 wrobell <wrobell@pld-linux.org> 2125052
- typo

* Mon Sep 24 2012 wrobell <wrobell@pld-linux.org> 6052609
- separate Java classes into subpackages (to not pull all Java deps)
- rel. 5

* Mon Sep 24 2012 Jan Rękorajski <baggins@pld-linux.org> e8368b7
- rebuild with fixed rpm macros
- release 4 (by relup.sh)

* Mon Sep 24 2012 Jan Rękorajski <baggins@pld-linux.org> df806e2
- parallel build doesn't quite work

